@@ -150,8 +150,9 @@ class AgspSession(object):
                     return abse
         return None
 
+
     """ 
-    Retourne un dataframe pour l'agribase pour la periode demandée 
+    Retourne un dataframe pour l'agribase pour la periode demandÃ©e 
     """
 
     def getAgribaseDataframe(self, agribase_p, from_p=None, to_p=None,index_by_sensor_id = False):
@@ -175,6 +176,43 @@ class AgspSession(object):
         :param from_p: From date
         :param to_p: To date.
         
+        :return: `Pandas <https://pandas.pydata.org/>`__  Dataframe with data
+        """
+
+        frame = self.getAgribaseDataframeDeep(agribase_p.serialNumber,from_p, to_p)
+
+        if index_by_sensor_id == False : # so index with sensor name
+            renaming_dict = dict()
+            for col in frame.columns :
+                sensor = agribase_p.getSensorByAgspSensorId(int(col))
+                renaming_dict[col] = sensor.name
+            frame.rename(columns=renaming_dict,inplace=True)
+
+        if frame is not None:
+            frame = frame.tz_convert(self.tz)
+        return frame
+
+    def getAgribaseDataframeDeep(self, agribase_serial_number, from_p=None, to_p=None):
+        """
+        getAgribaseDataframe
+        --------------------
+        Return a `Pandas <https://pandas.pydata.org/>`__  Dataframe fill with data
+        generated by the Agribase.
+        It gets data from the Agriscope Server.
+        The :timezone used is the timezone used by the session
+        
+        Use the period specified by the from_p and the to_p parameters.
+        
+        If from_p AND to_p is not specified, the period is choosen automatically from
+        [now - 3 days => now]
+        
+        If from_p is not specified and to_p is specified, the function return a range 
+        between [to_p - 3 days => to_p]
+                
+        :param agribase_p: Agribase object wanted.
+        :param from_p: From date
+        :param to_p: To date.
+        
         :return: `Pandas <https://pandas.pydata.org/>`__  Dataframe with data
         """
         frame = pd.DataFrame()
@@ -185,13 +223,10 @@ class AgspSession(object):
         if from_p == None:
             from_p = to_p - timedelta(days=3)
         
-        result_dict = self.__loadAgribaseDataFlat(agribase_p.serialNumber,from_p,to_p) 
+        result_dict = self.__loadAgribaseDataFlat(agribase_serial_number,from_p,to_p) 
         for sensor_id in result_dict.keys():
             dates,values = result_dict[sensor_id]
-            sensor = agribase_p.getSensorByAgspSensorId(sensor_id)
-            label= sensor.name
-            if index_by_sensor_id == True :
-                label = "%d"%sensor_id
+            label= "%d"%sensor_id
             df = self.__convertDataToPandasFrame(dates, values, label)
             if df is not None and len(df) > 0:
                 # print frame.head()
@@ -201,6 +236,8 @@ class AgspSession(object):
             frame = frame.tz_convert(self.tz)
         return frame
 
+   
+
     
     """ 
     Retourne un dataframe pour l'agribase sur l'instant donnée [+/- 1 seconde]
